citem_t

Struct citem_t 

pub struct citem_t { /* private fields */ }
Basic ctree item. This is an abstract class (but we don’t use virtual functions in ctree, so the compiler will not disallow you to create citem_t instances). However, items of pure citem_t type must never be created. Two classes, cexpr_t and cinsn_t are derived from it.

Implementations



impl citem_t

pub unsafe fn is_expr(&self) -> bool

Is an expression?

pub unsafe fn contains_expr(&self, e: *const cexpr_t) -> bool

Does the item contain an expression?

pub unsafe fn contains_label(&self) -> bool

Does the item contain a label?

pub unsafe fn find_parent_of(&self, item: *const citem_t) -> *const citem_t

Find parent of the specified item. \param item Item to find the parent of. The search will be performed among the children of the item pointed by \c this. \return nullptr if not found

pub unsafe fn find_parent_of1( self: Pin<&mut Self>, item: *const citem_t, ) -> *mut citem_t

pub unsafe fn find_closest_addr( self: Pin<&mut Self>, _ea: c_ulonglong, ) -> *mut citem_t

pub unsafe fn print1( &self, vout: *mut qstring_char_AutocxxConcrete, func: *const cfunc_t, )

Print item into one line. \param vout output buffer \param func parent function. This argument is used to find out the referenced variable names. \return length of the generated text.



impl citem_t

pub unsafe fn swap(self: Pin<&mut citem_t>, r: Pin<&mut citem_t>)

Swap two citem_t

pub unsafe fn new(o: ctype_t) -> impl New<Output = Self>